==> 0.0.2-rc7.tar.gz: android/src/main/java/com/weebkun/speedq_printer/BluetoothManager.java <==
package com.weebkun.speedq_printer;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.IBinder;
import android.util.Log;

import net.posprinter.posprinterface.IMyBinder;
import net.posprinter.posprinterface.UiExecute;
import net.posprinter.service.PosprinterService;
import net.posprinter.utils.DataForSendToPrinterPos58;
import net.posprinter.utils.DataForSendToPrinterPos80;

import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;

/**
 * class to manage bluetooth discovery, connections, and devices
 */
public class BluetoothManager {
    private static final BluetoothAdapter adapter = BluetoothAdapter.getDefaultAdapter();
    private static IMyBinder binder;

    private static final ServiceConnection conn = new ServiceConnection() {
        @Override
        public void onServiceConnected(ComponentName componentName, IBinder iBinder) {
            //Bind successfully
            binder= (IMyBinder) iBinder;
        }

        @Override
        public void onServiceDisconnected(ComponentName componentName) {
        }
    };

    public static Device[] getPairedDevices() {
        Set<BluetoothDevice> devices = adapter.getBondedDevices();
        for(BluetoothDevice device : devices) {
            System.out.println(device.getName());
        }
        return devices.stream().map(Device::new).toArray(Device[]::new);
    }

    public static void connect(String mac, Context context) {
        context.bindService(new Intent(context, PosprinterService.class), conn, Context.BIND_AUTO_CREATE);

        binder.connectBtPort(mac, new UiExecute() {
            @Override
            public void onsucess() {
                Log.i("bt", "connected to printer");
                binder.write(DataForSendToPrinterPos80.openOrCloseAutoReturnPrintState(0x1f), new UiExecute() {
                    @Override
                    public void onsucess() {
                        binder.acceptdatafromprinter(new UiExecute() {
                            @Override
                            public void onsucess() {
                            }

                            @Override
                            public void onfailed() {
                            }
                        });
                    }

                    @Override
                    public void onfailed() {
                    }
                });
            }

            @Override
            public void onfailed() {
                Log.e("bt", "cannot connect");
            }
        });
    }

    public static void printText(String text){

        binder.writeDataByYouself(
                new UiExecute() {
                    @Override
                    public void onsucess() {

                    }

                    @Override
                    public void onfailed() {

                    }
                }, () -> {

                List<byte[]> list = new ArrayList<>();
                //initialize the printer
//                            list.add( DataForSendToPrinterPos58.initializePrinter());
                list.add(DataForSendToPrinterPos58.initializePrinter());
                byte[] data1 = stringToBytes(text);
                list.add(data1);
                //should add the command of print and feed line,because print only when one line is complete, not one line, no print
                list.add(DataForSendToPrinterPos58.printAndFeedLine());
                return list;
                });
    }

    public static byte[] stringToBytes(String str){
        byte[] data = null;
        try {
            data = str.getBytes("gbk");
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }
        return data;
    }
}

==> 0.0.3-rc1.tar.gz: android/src/main/java/com/weebkun/speedq_printer/BluetoothManager.java <==
package com.weebkun.speedq_printer;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.IBinder;
import android.util.Log;

import net.posprinter.posprinterface.IMyBinder;
import net.posprinter.posprinterface.UiExecute;
import net.posprinter.service.PosprinterService;
import net.posprinter.utils.DataForSendToPrinterPos58;
import net.posprinter.utils.DataForSendToPrinterPos80;

import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;

/**
 * class to manage bluetooth discovery, connections, and devices
 */
public class BluetoothManager {
    private static final BluetoothAdapter adapter = BluetoothAdapter.getDefaultAdapter();
    private static IMyBinder binder;

    private static final ServiceConnection conn = new ServiceConnection() {
        @Override
        public void onServiceConnected(ComponentName componentName, IBinder iBinder) {
            //Bind successfully
            binder = (IMyBinder) iBinder;
        }

        @Override
        public void onServiceDisconnected(ComponentName componentName) {
        }
    };

    public static Device[] getPairedDevices() {
        Device[] devices = adapter.getBondedDevices().stream().map(Device::new).toArray(Device[]::new);
        for(Device device : devices) {
            System.out.println(device.name);
        }
        return devices;
    }

    public static void connect(String mac, Context context) {
        if(binder != null) {
            binder.connectBtPort(mac, new UiExecute() {
                @Override
                public void onsucess() {
                    Log.i("bt", "connected to printer");
                    binder.write(DataForSendToPrinterPos80.openOrCloseAutoReturnPrintState(0x1f), new UiExecute() {
                        @Override
                        public void onsucess() {
                            binder.acceptdatafromprinter(new UiExecute() {
                                @Override
                                public void onsucess() {
                                }

                                @Override
                                public void onfailed() {
                                }
                            });
                        }

                        @Override
                        public void onfailed() {
                        }
                    });
                }

                @Override
                public void onfailed() {
                    Log.e("bt", "cannot connect");
                }
            });
        } else {
            bindService(context);
            connect(mac, context);
        }
    }

    public static void bindService(Context context) {
        context.bindService(new Intent(context, PosprinterService.class), conn, Context.BIND_AUTO_CREATE);
    }

    public static void printText(String text){

        binder.writeDataByYouself(
                new UiExecute() {
                    @Override
                    public void onsucess() {

                    }

                    @Override
                    public void onfailed() {

                    }
                }, () -> {

                List<byte[]> list = new ArrayList<>();
                //initialize the printer
//                            list.add( DataForSendToPrinterPos58.initializePrinter());
                list.add(DataForSendToPrinterPos58.initializePrinter());
                byte[] data1 = stringToBytes(text);
                list.add(data1);
                //should add the command of print and feed line,because print only when one line is complete, not one line, no print
                list.add(DataForSendToPrinterPos58.printAndFeedLine());
                return list;
                });
    }

    public static byte[] stringToBytes(String str){
        byte[] data = null;
        try {
            data = str.getBytes("gbk");
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }
        return data;
    }
}
